package main

import (
	"fmt"
	"os"
	"time"

	openapi "github.com/alibabacloud-go/darabonba-openapi/v2/client"
	swas_open20200601 "github.com/alibabacloud-go/swas-open-20200601/client"
	"github.com/alibabacloud-go/tea/tea"
)

func CreateClient(Key, Secret string) (_result *swas_open20200601.Client, _err error) {
	config := &openapi.Config{
		AccessKeyId:     tea.String(Key),
		AccessKeySecret: tea.String(Secret),
	}
	config.Endpoint = tea.String("swas.cn-hongkong.aliyuncs.com")
	_result = &swas_open20200601.Client{}
	_result, _err = swas_open20200601.NewClient(config)
	return _result, _err
}

func SDKCreate(Key, Secret string) error {
	client, err := CreateClient(Key, Secret)
	if err != nil {
		return err
	}
	request := &swas_open20200601.CreateInstancesRequest{
		RegionId: tea.String("cn-hongkong"),                      // 香港
		ImageId:  tea.String("8b798eb927684a08b26bb95da94f5812"), // Debian11
		PlanId:   tea.String("swas.s2.c2m1s40b30t1.un"),          // 轻量24
		Period:   tea.Int32(1),
	}
	_, err = client.CreateInstances(request)
	if err != nil {
		return err
	}
	return nil
}

func main() {
	location, err := time.LoadLocation("Asia/Shanghai")
	if err != nil {
		fmt.Println("Error loading location:", err)
		return
	}
	time.Local = location
	args := os.Args
	if len(args) < 3 {
		fmt.Printf("Usage: %s <AccessKeyId> <AccessKeySecret>\n", args[0])
		return
	}

	// 手动执行一次
	err = SDKCreate(args[1], args[2])
	if err != nil {
		fmt.Printf("Error: %s\n", err)
	} else {
		fmt.Println("Success! Please check it in your aliyun console.")
	}

	fmt.Println("Done")
}
